/**
 * @file CrFwOutFactoryUserPar.h
 * @ingroup CrIaConfig
 * @authors FW Profile code generator, P&P Software GmbH, 2015; Institute for Astrophysics, 2015-2016
 *
 * @brief User-modifiable parameters for the OutFactory component of the IASW application.
 *
 * @copyright
 * This program is free software; you can redistribute it and/or modify it
 * under the terms and conditions of the GNU General Public License,
 * version 2, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 */

#ifndef CRFW_OUT_FACTORY_USER_PAR_H
#define CRFW_OUT_FACTORY_USER_PAR_H

#include <Services/General/CrIaConstants.h>
#include <Services/General/CrSemConstants.h>
#include <CrFwConstants.h>
#include <UtilityFunctions/CrFwUtilityFunctions.h>
#include <CrIaOutCmp.h>

#include <Services/CrIaServ1CommandVerificationService/OutRep/CrIaServ1AccSucc.h>
#include <Services/CrIaServ1CommandVerificationService/OutRep/CrIaServ1AccFail.h>
#include <Services/CrIaServ1CommandVerificationService/OutRep/CrIaServ1StartSucc.h>
#include <Services/CrIaServ1CommandVerificationService/OutRep/CrIaServ1StartFail.h>
#include <Services/CrIaServ1CommandVerificationService/OutRep/CrIaServ1TermSucc.h>
#include <Services/CrIaServ1CommandVerificationService/OutRep/CrIaServ1TermFail.h>
#include <Services/CrIaServ3HousekeepingDataReportingService/OutRep/CrIaServ3HkDr.h>
#include <Services/CrIaServ5EventReportingService/OutRep/CrIaServ5Event.h>
#include <Services/CrIaServ6MemoryManagementService/OutRep/CrIaServ6MemDump.h>
#include <Services/CrIaServ13LargeDataTransferService/OutRep/CrIaServ13FstDwlk.h>
#include <Services/CrIaServ13LargeDataTransferService/OutRep/CrIaServ13IntmDwlk.h>
#include <Services/CrIaServ13LargeDataTransferService/OutRep/CrIaServ13LastDwlk.h>
#include <Services/CrIaServ13LargeDataTransferService/OutRep/CrIaServ13DwlkAbrt.h>
#include <Services/CrIaServ195HeartbeatService/OutRep/CrIaServ195HbRep.h>
#include <Services/CrIaServ196AOCSService/OutRep/CrIaServ196AocsRep.h>
#include <Services/CrIaServ197BootReportService/OutRep/CrIaServ197BootRep.h>

#include <Services/CrSemServ9HousekeepingDataReportingService/OutCmd/CrSemServ9CmdTimeUpdate.h>
#include <Services/CrSemServ21ScienceDataService/OutCmd/CrSemServ21CmdCcdDataEnable.h>
#include <Services/CrSemServ21ScienceDataService/OutCmd/CrSemServ21CmdCcdDataDisable.h>
#include <Services/CrSemServ220PrivateService220/OutCmd/CrSemServ220CmdOperParam.h>
#include <Services/CrSemServ220PrivateService220/OutCmd/CrSemServ220CmdTempCtrlEnable.h>
#include <Services/CrSemServ220PrivateService220/OutCmd/CrSemServ220CmdFunctParam.h>
#include <Services/CrSemServ221PrivateService221/OutCmd/CrSemServ221FpmPowerEnb.h>
#include <Services/CrSemServ221PrivateService221/OutCmd/CrSemServ221FpmPowerDis.h>
#include <Services/CrSemServ222PrivateService222/OutCmd/CrSemServ222DiagEnable.h>

/**
 * The maximum number of OutComponents which may be allocated at any one time.
 * This constant must be smaller than the range of CrFwOutFactoryPoolIndex_t.
 */

#define CR_FW_OUTFACTORY_MAX_NOF_OUTCMP 74 /* has to be the same as POCL size */


/**
 * Definition of the OutComponent kinds supported by an application.
 */


#define CR_FW_OUTCMP_INIT_KIND_DESC\
	{\
{CRIA_SERV1,     CRIA_SERV1_ACC_SUCC,                 0,                             crRepType,  CRIA_SERV1_ACC_SUCC_LENGTH,                 &CrFwSmCheckAlwaysTrue,               &CrFwSmCheckAlwaysTrue,         &CrFwSmCheckAlwaysFalse,     &CrIaServ1AccSuccUpdateAction,               &CrIaOutCmpDefSerialize},\
{CRIA_SERV1,     CRIA_SERV1_ACC_FAIL,                 0,                             crRepType,  CRIA_SERV1_ACC_FAIL_LENGTH,                 &CrFwSmCheckAlwaysTrue,               &CrFwSmCheckAlwaysTrue,         &CrFwSmCheckAlwaysFalse,     &CrIaServ1AccFailUpdateAction,               &CrIaOutCmpDefSerialize},\
{CRIA_SERV1,     CRIA_SERV1_START_SUCC,               0,                             crRepType,  CRIA_SERV1_START_SUCC_LENGTH,               &CrFwSmCheckAlwaysTrue,               &CrFwSmCheckAlwaysTrue,         &CrFwSmCheckAlwaysFalse,     &CrIaServ1StartSuccUpdateAction,             &CrIaOutCmpDefSerialize},\
{CRIA_SERV1,     CRIA_SERV1_START_FAIL,               0,                             crRepType,  CRIA_SERV1_START_FAIL_LENGTH,               &CrFwSmCheckAlwaysTrue,               &CrFwSmCheckAlwaysTrue,         &CrFwSmCheckAlwaysFalse,     &CrIaServ1StartFailUpdateAction,             &CrIaOutCmpDefSerialize},\
{CRIA_SERV1,     CRIA_SERV1_TERM_SUCC,                0,                             crRepType,  CRIA_SERV1_TERM_SUCC_LENGTH,                &CrFwSmCheckAlwaysTrue,               &CrFwSmCheckAlwaysTrue,         &CrFwSmCheckAlwaysFalse,     &CrIaServ1TermSuccUpdateAction,              &CrIaOutCmpDefSerialize},\
{CRIA_SERV1,     CRIA_SERV1_TERM_FAIL,                0,                             crRepType,  CRIA_SERV1_TERM_FAIL_LENGTH,                &CrFwSmCheckAlwaysTrue,               &CrFwSmCheckAlwaysTrue,         &CrFwSmCheckAlwaysFalse,     &CrIaServ1TermFailUpdateAction,              &CrIaOutCmpDefSerialize},\
{CRSEM_SERV3,    CRSEM_SERV3_CMD_HK_ENABLE,           0,                             crCmdType,  CRSEM_SERV3_CMD_HK_ENABLE_LENGTH,           &CrFwSmCheckAlwaysTrue,               &CrFwSmCheckAlwaysTrue,         &CrFwSmCheckAlwaysFalse,     &CrFwSmEmptyAction,                          &CrIaOutCmpDefSerialize},\
{CRSEM_SERV3,    CRSEM_SERV3_CMD_HK_DISABLE,          0,                             crCmdType,  CRSEM_SERV3_CMD_HK_DISABLE_LENGTH,          &CrFwSmCheckAlwaysTrue,               &CrFwSmCheckAlwaysTrue,         &CrFwSmCheckAlwaysFalse,     &CrFwSmEmptyAction,                          &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    1,                             crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    2,                             crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    3,                             crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    4,                             crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    5,                             crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    6,                             crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    7,                             crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    8,                             crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    9,                             crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    10,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    11,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    12,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    13,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    14,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    15,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    16,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    17,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    18,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    19,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    20,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    21,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    22,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    23,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    24,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    25,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    26,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    27,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    28,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    29,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    30,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    31,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    32,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    33,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    34,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    35,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    36,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    37,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    38,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    39,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    40,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    41,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    42,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    43,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    44,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    45,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    46,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    47,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    48,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    49,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRIA_SERV3,     CRIA_SERV3_HK_DR,                    50,                            crRepType,  CRIA_SERV3_HK_DR_LENGTH,                    &CrIaServ3HkDrEnableCheck,            &CrIaServ3HkDrReadyCheck,       &CrFwSmCheckAlwaysTrue,      &CrIaServ3HkDrUpdateAction,                  &CrIaOutCmpDefSerialize},\
{CRSEM_SERV3,    CRSEM_SERV3_CMD_HK_PERIOD,           0,                             crCmdType,  CRSEM_SERV3_CMD_HK_PERIOD_LENGTH,           &CrFwSmCheckAlwaysTrue,               &CrFwSmCheckAlwaysTrue,         &CrFwSmCheckAlwaysFalse,     &CrFwSmEmptyAction,                          &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_NORM,                 CRIA_SERV5_EVT_SEM_TR,         crRepType,  CRIA_SERV5_EVT_SEM_TR_LENGTH,               &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_NORM,                 CRIA_SERV5_EVT_IASW_TR,        crRepType,  CRIA_SERV5_EVT_IASW_TR_LENGTH,              &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_NORM,                 CRIA_SERV5_EVT_SEMOP_TR,       crRepType,  CRIA_SERV5_EVT_SEMOP_TR_LENGTH,             &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_NORM,                 CRIA_SERV5_EVT_SC_PR_STRT,     crRepType,  CRIA_SERV5_EVT_SC_PR_STRT_LENGTH,           &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_NORM,                 CRIA_SERV5_EVT_SC_PR_END,      crRepType,  CRIA_SERV5_EVT_SC_PR_END_LENGTH,            &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_NORM,                 CRIA_SERV5_EVT_INIT_SUCC,      crRepType,  CRIA_SERV5_EVT_INIT_SUCC_LENGTH,            &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_LOW_SEV,          CRIA_SERV5_EVT_SEQ_CNT_ERR,    crRepType,  CRIA_SERV5_EVT_SEQ_CNT_ERR_LENGTH,          &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_LOW_SEV,          CRIA_SERV5_EVT_1553_ERR_L,     crRepType,  CRIA_SERV5_EVT_1553_ERR_L_LENGTH,           &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_LOW_SEV,          CRIA_SERV5_EVT_SPW_ERR_L,      crRepType,  CRIA_SERV5_EVT_SPW_ERR_L_LENGTH,            &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_LOW_SEV,          CRIA_SERV5_EVT_SBIT_ERR,       crRepType,  CRIA_SERV5_EVT_SBIT_ERR_LENGTH,             &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_MED_SEV,          CRIA_SERV5_EVT_INV_DEST,       crRepType,  CRIA_SERV5_EVT_INV_DEST_LENGTH,             &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_MED_SEV,          CRIA_SERV5_EVT_INREP_CR_FAIL,  crRepType,  CRIA_SERV5_EVT_INREP_CR_FAIL_LENGTH,        &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_MED_SEV,          CRIA_SERV5_EVT_PCRL2_FULL,     crRepType,  CRIA_SERV5_EVT_PCRL2_FULL_LENGTH,           &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_MED_SEV,          CRIA_SERV5_EVT_FD_FAILED,      crRepType,  CRIA_SERV5_EVT_FD_FAILED_LENGTH,            &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_MED_SEV,          CRIA_SERV5_EVT_SDSC_ILL,       crRepType,  CRIA_SERV5_EVT_SDSC_ILL_LENGTH,             &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_MED_SEV,          CRIA_SERV5_EVT_SDSC_OOS,       crRepType,  CRIA_SERV5_EVT_SDSC_OOS_LENGTH,             &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_MED_SEV,          CRIA_SERV5_EVT_CLCT_SIZE,      crRepType,  CRIA_SERV5_EVT_CLCT_SIZE_LENGTH,            &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_MED_SEV,          CRIA_SERV5_EVT_SIB_SIZE,       crRepType,  CRIA_SERV5_EVT_SIB_SIZE_LENGTH,             &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_MED_SEV,          CRIA_SERV5_EVT_FBF_LOAD_RISK,  crRepType,  CRIA_SERV5_EVT_FBF_LOAD_RISK_LENGTH,        &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_MED_SEV,          CRIA_SERV5_EVT_FBF_SAVE_DENIED, crRepType, CRIA_SERV5_EVT_FBF_SAVE_DENIED_LENGTH,      &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_MED_SEV,          CRIA_SERV5_EVT_FBF_SAVE_ABRT,  crRepType,  CRIA_SERV5_EVT_FBF_SAVE_ABRT_LENGTH,        &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_MED_SEV,          CRIA_SERV5_EVT_SDB_CNF_FAIL,   crRepType,  CRIA_SERV5_EVT_SDB_CNF_FAIL_LENGTH,         &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_MED_SEV,          CRIA_SERV5_EVT_CMPR_SIZE,      crRepType,  CRIA_SERV5_EVT_CMPR_SIZE_LENGTH,            &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_MED_SEV,          CRIA_SERV5_EVT_INSTRM_PQF,     crRepType,  CRIA_SERV5_EVT_INSTRM_PQF_LENGTH,           &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_MED_SEV,          CRIA_SERV5_EVT_OCMP_INVD,      crRepType,  CRIA_SERV5_EVT_OCMP_INVD_LENGTH,            &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_MED_SEV,          CRIA_SERV5_EVT_OCMP_ILLGR,     crRepType,  CRIA_SERV5_EVT_OCMP_ILLGR_LENGTH,           &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_MED_SEV,          CRIA_SERV5_EVT_IN_ILLGR,       crRepType,  CRIA_SERV5_EVT_IN_ILLGR_LENGTH,             &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_MED_SEV,          CRIA_SERV5_EVT_INV_CENT,       crRepType,  CRIA_SERV5_EVT_INV_CENT_LENGTH,             &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_MED_SEV,          CRIA_SERV5_EVT_OOL_PARAM,      crRepType,  CRIA_SERV5_EVT_OOL_PARAM_LENGTH,            &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_MED_SEV,          CRIA_SERV5_EVT_1553_ERR_M,     crRepType,  CRIA_SERV5_EVT_1553_ERR_M_LENGTH,           &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_MED_SEV,          CRIA_SERV5_EVT_SPW_ERR_M,      crRepType,  CRIA_SERV5_EVT_SPW_ERR_M_LENGTH,            &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_MED_SEV,          CRIA_SERV5_EVT_FL_FBF_BB,      crRepType,  CRIA_SERV5_EVT_FL_FBF_BB_LENGTH,            &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_MED_SEV,          CRIA_SERV5_EVT_DBIT_ERR,       crRepType,  CRIA_SERV5_EVT_DBIT_ERR_LENGTH,             &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_MED_SEV,          CRIA_SERV5_EVT_SYNC_LOSS,      crRepType,  CRIA_SERV5_EVT_SYNC_LOSS_LENGTH,            &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_MED_SEV,          CRIA_SERV5_EVT_SDP_NOMEM,      crRepType,  CRIA_SERV5_EVT_SDP_NOMEM_LENGTH,            &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_MED_SEV,          CRIA_SERV5_EVT_SEM_ILL_ST,     crRepType,  CRIA_SERV5_EVT_SEM_ILL_ST_LENGTH,           &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_MED_SEV,          CRIA_SERV5_EVT_ACQ_FAIL,       crRepType,  CRIA_SERV5_EVT_ACQ_FAIL_LENGTH,             &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_MED_SEV,          CRIA_SERV5_EVT_PROCBUF_INSUF,  crRepType,  CRIA_SERV5_EVT_PROCBUF_INSUF_LENGTH,        &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_MED_SEV,          CRIA_SERV5_EVT_XIB_FULL,       crRepType,  CRIA_SERV5_EVT_XIB_FULL_LENGTH,             &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_MED_SEV,          CRIA_SERV5_EVT_IMG_INSUF,      crRepType,  CRIA_SERV5_EVT_IMG_INSUF_LENGTH,            &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,       CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_HIGH_SEV,         CRIA_SERV5_EVT_RP_STARTED,     crRepType,  CRIA_SERV5_EVT_RP_STARTED_LENGTH,           &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_HIGH_SEV,         CRIA_SERV5_EVT_INIT_FAIL,      crRepType,  CRIA_SERV5_EVT_INIT_FAIL_LENGTH,            &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_HIGH_SEV,         CRIA_SERV5_EVT_THRD_OR,        crRepType,  CRIA_SERV5_EVT_THRD_OR_LENGTH,              &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_HIGH_SEV,         CRIA_SERV5_EVT_NOTIF_ERR,      crRepType,  CRIA_SERV5_EVT_NOTIF_ERR_LENGTH,            &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_HIGH_SEV,         CRIA_SERV5_EVT_1553_ERR_H,     crRepType,  CRIA_SERV5_EVT_1553_ERR_H_LENGTH,           &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_HIGH_SEV,         CRIA_SERV5_EVT_SPW_ERR_H,      crRepType,  CRIA_SERV5_EVT_SPW_ERR_H_LENGTH,            &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_HIGH_SEV,         CRIA_SERV5_EVT_FL_EL_ERR,      crRepType,  CRIA_SERV5_EVT_FL_EL_ERR_LENGTH,            &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV5,     CRIA_SERV5_EVT_ERR_HIGH_SEV,         CRIA_SERV5_EVT_FL_FBF_ERR,     crRepType,  CRIA_SERV5_EVT_FL_FBF_ERR_LENGTH,           &CrIaServ5EventEnableCheck,           &CrIaServ5EventReadyCheck,      &CrIaServ5EventRepeatCheck,  &CrIaServ5EventUpdateAction,                 &CrIaOutCmpDefSerialize},\
{CRIA_SERV6,     CRIA_SERV6_MEM_DUMP,                 0,                             crRepType,  CRIA_SERV6_MEM_DUMP_LENGTH,                 &CrFwSmCheckAlwaysTrue,               &CrFwSmCheckAlwaysTrue,         &CrFwSmCheckAlwaysFalse,     &CrIaServ6MemDumpUpdateAction,               &CrIaOutCmpDefSerialize},\
{CRSEM_SERV9,    CRSEM_SERV9_CMD_TIME_UPDATE,         0,                             crCmdType,  CRSEM_SERV9_CMD_TIME_UPDATE_LENGTH,         &CrSemServ9CmdTimeUpdateEnableCheck,  &CrSemServ9CmdTimeUpdateReadyCheck, &CrSemServ9CmdTimeUpdateRepeatCheck, &CrSemServ9CmdTimeUpdateUpdateAction, &CrIaOutCmpDefSerialize},\
{CRIA_SERV13,    CRIA_SERV13_FST_DWLK,                0,                             crRepType,  CRIA_SERV13_FST_DWLK_LENGTH,                &CrFwSmCheckAlwaysTrue,               &CrFwSmCheckAlwaysTrue,         &CrFwSmCheckAlwaysFalse,     &CrIaServ13FstDwlkUpdateAction,              &CrIaOutCmpDefSerialize},\
{CRIA_SERV13,    CRIA_SERV13_INTM_DWLK,               0,                             crRepType,  CRIA_SERV13_INTM_DWLK_LENGTH,               &CrFwSmCheckAlwaysTrue,               &CrFwSmCheckAlwaysTrue,         &CrFwSmCheckAlwaysFalse,     &CrIaServ13IntmDwlkUpdateAction,             &CrIaOutCmpDefSerialize},\
{CRIA_SERV13,    CRIA_SERV13_LAST_DWLK,               0,                             crRepType,  CRIA_SERV13_LAST_DWLK_LENGTH,               &CrFwSmCheckAlwaysTrue,               &CrFwSmCheckAlwaysTrue,         &CrFwSmCheckAlwaysFalse,     &CrIaServ13LastDwlkUpdateAction,             &CrIaOutCmpDefSerialize},\
{CRIA_SERV13,    CRIA_SERV13_DWLK_ABRT,               0,                             crRepType,  CRIA_SERV13_DWLK_ABRT_LENGTH,               &CrFwSmCheckAlwaysTrue,               &CrFwSmCheckAlwaysTrue,         &CrFwSmCheckAlwaysFalse,     &CrIaServ13DwlkAbrtUpdateAction,             &CrIaOutCmpDefSerialize},\
{CRIA_SERV17,    CRIA_SERV17_LINK_CONN_REP,           0,                             crRepType,  CRIA_SERV17_LINK_CONN_REP_LENGTH,           &CrFwSmCheckAlwaysTrue,               &CrFwSmCheckAlwaysTrue,         &CrFwSmCheckAlwaysFalse,     &CrFwSmEmptyAction,                          &CrIaOutCmpDefSerialize},\
{CRSEM_SERV21,   CRSEM_SERV21_CMD_CCD_DATA_ENABLE,    0,                             crCmdType,  CRSEM_SERV21_CMD_CCD_DATA_ENABLE_LENGTH,    &CrFwSmCheckAlwaysTrue,               &CrFwSmCheckAlwaysTrue,         &CrFwSmCheckAlwaysFalse,     &CrSemServ21CmdCcdDataEnableUpdateAction,    &CrIaOutCmpDefSerialize},\
{CRSEM_SERV21,   CRSEM_SERV21_CMD_CCD_DATA_DISABLE,   0,                             crCmdType,  CRSEM_SERV21_CMD_CCD_DATA_DISABLE_LENGTH,   &CrFwSmCheckAlwaysTrue,               &CrFwSmCheckAlwaysTrue,         &CrFwSmCheckAlwaysFalse,     &CrSemServ21CmdCcdDataDisableUpdateAction,   &CrIaOutCmpDefSerialize},\
{CRIA_SERV195,   CRIA_SERV195_HB_REP,                 0,                             crRepType,  CRIA_SERV195_HB_REP_LENGTH,                 &CrFwSmCheckAlwaysTrue,               &CrIaServ195HbRepReadyCheck,    &CrFwSmCheckAlwaysTrue,      &CrIaServ195HbRepUpdateAction,               &CrIaOutCmpDefSerialize},\
{CRIA_SERV196,   CRIA_SERV196_AOCS_REP,               0,                             crRepType,  CRIA_SERV196_AOCS_REP_LENGTH,               &CrIaServ196AocsRepEnableCheck,       &CrIaServ196AocsRepReadyCheck,  &CrFwSmCheckAlwaysTrue,      &CrIaServ196AocsRepUpdateAction,             &CrIaOutCmpDefSerialize},\
{CRIA_SERV197,   CRIA_SERV197_BOOT_REP,               0,                             crRepType,  CRIA_SERV197_BOOT_REP_LENGTH,               &CrFwSmCheckAlwaysTrue,               &CrFwSmCheckAlwaysTrue,         &CrFwSmCheckAlwaysFalse,     &CrIaServ197BootRepUpdateAction,             &CrIaOutCmpDefSerialize},\
{CRSEM_SERV220,  CRSEM_SERV220_CMD_OPER_PARAM,        0,                             crCmdType,  CRSEM_SERV220_CMD_OPER_PARAM_LENGTH,        &CrFwSmCheckAlwaysTrue,               &CrFwSmCheckAlwaysTrue,         &CrFwSmCheckAlwaysFalse,     &CrSemServ220CmdOperParamUpdateAction,       &CrIaOutCmpDefSerialize},\
{CRSEM_SERV220,  CRSEM_SERV220_CMD_TEMP_CTRL_ENABLE,  0,                             crCmdType,  CRSEM_SERV220_CMD_TEMP_CTRL_ENABLE_LENGTH,  &CrFwSmCheckAlwaysTrue,               &CrFwSmCheckAlwaysTrue,         &CrFwSmCheckAlwaysFalse,     &CrSemServ220CmdTempCtrlEnableUpdateAction,  &CrIaOutCmpDefSerialize},\
{CRSEM_SERV220,  CRSEM_SERV220_CMD_FUNCT_PARAM,       0,                             crCmdType,  CRSEM_SERV220_CMD_FUNCT_PARAM_LENGTH,       &CrFwSmCheckAlwaysTrue,               &CrFwSmCheckAlwaysTrue,         &CrFwSmCheckAlwaysFalse,     &CrSemServ220CmdFunctParamUpdateAction,      &CrIaOutCmpDefSerialize},\
{CRSEM_SERV221,  CRSEM_SERV221_CMD_SAFE_ENTER,        0,                             crCmdType,  CRSEM_SERV221_CMD_SAFE_ENTER_LENGTH,        &CrFwSmCheckAlwaysTrue,               &CrFwSmCheckAlwaysTrue,         &CrFwSmCheckAlwaysFalse,     &CrFwSmEmptyAction,                          &CrIaOutCmpDefSerialize},\
{CRSEM_SERV221,  CRSEM_SERV221_CMD_STANDBY_ENTER,     0,                             crCmdType,  CRSEM_SERV221_CMD_STANDBY_ENTER_LENGTH,     &CrFwSmCheckAlwaysTrue,               &CrFwSmCheckAlwaysTrue,         &CrFwSmCheckAlwaysFalse,     &CrFwSmEmptyAction,                          &CrIaOutCmpDefSerialize},\
{CRSEM_SERV221,  CRSEM_SERV221_CMD_FPM_POWER_ENABLE,  0,                             crCmdType,  CRSEM_SERV221_CMD_FPM_POWER_ENABLE_LENGTH,  &CrFwSmCheckAlwaysTrue,               &CrFwSmCheckAlwaysTrue,         &CrFwSmCheckAlwaysFalse,     &CrSemServ221CmdFpmPowerEnableUpdateAction,  &CrIaOutCmpDefSerialize},\
{CRSEM_SERV221,  CRSEM_SERV221_CMD_FPM_POWER_DISABLE, 0,                             crCmdType,  CRSEM_SERV221_CMD_FPM_POWER_DISABLE_LENGTH, &CrFwSmCheckAlwaysTrue,               &CrFwSmCheckAlwaysTrue,         &CrFwSmCheckAlwaysFalse,     &CrSemServ221CmdFpmPowerDisableUpdateAction, &CrIaOutCmpDefSerialize},\
{CRSEM_SERV222,  CRSEM_SERV222_CMD_DIAG_ENABLE,       0,                             crCmdType,  CRSEM_SERV222_CMD_DIAG_ENABLE_LENGTH,       &CrFwSmCheckAlwaysTrue,               &CrFwSmCheckAlwaysTrue,         &CrFwSmCheckAlwaysFalse,     &CrSemServ222CmdDiagEnableUpdateAction,      &CrIaOutCmpDefSerialize},\
{CRSEM_SERV222,  CRSEM_SERV222_CMD_DIAG_DISABLE,      0,                             crCmdType,  CRSEM_SERV222_CMD_DIAG_DISABLE_LENGTH,      &CrFwSmCheckAlwaysTrue,               &CrFwSmCheckAlwaysTrue,         &CrFwSmCheckAlwaysFalse,     &CrFwSmEmptyAction,                          &CrIaOutCmpDefSerialize}\
}

/**
 * The total number of kinds of OutComponents supported by the application.
 */
#define CR_FW_OUTCMP_NKINDS 128

#endif /* CRFW_OUT_FACTORY_USER_PAR_H */


