/**
 * @file
 * This header file declares the function to create one instance of the CrIaAlgo state machine.
 * The state machine is configured with a set of function pointers representing the non-default
 * actions and guards of the state machine. Some of these functions may also be declared in
 * this header file in accordance with the configuration of the state machine in the FW Profile
 * Editor. In the latter case, the user has to provide an implementation for these functions
 * in a user-supplied body file.
 *
 * This header file has been automatically generated by the FW Profile Editor.
 * The state machine created by this file is shown in the figure below.
 *
 * <b>Note for state ACTIVE</b>
 * The algorithm period and phase which are needed to 
 * evaluate Flag_1 are accessed through the pointers
 * stored in the algorithm data structure.
 * 
 * The state actions execute the functions implementing the
 * algorithm Initialization Action, Execution Action and Finalization
 * Action. The pointers to these functions are retrieved from
 * the algorithm data structure.
 *
 * <b>Note for Transition from INACTIVE to ACTIVE</b>
 * The function implementing the guard on this transition 
 * accesses the enable state of an algorithm through the 
 * pointer stored in the algorithm data structure.
 *
 * <b>Note for Transition from SUSPENDED to INACTIVE</b>
 * The transition action executes the function which implements the 
 * Finalization Action for the algorithm. 
 * The pointer to this function is retrieved from the 
 * algorithm data structure.
 *
 * @image html CrIaAlgo.png
 *
 * @author FW Profile code generator version 4.63
 * @date Created on: Feb 11 2016 22:56:45
 */

/** Make sure to include this header file only once */
#ifndef CrIaAlgoCreate_H_
#define CrIaAlgoCreate_H_

/** FW Profile function definitions */
#include "FwProfile/FwSmConstants.h"

/** State identifiers */
#define CrIaAlgo_OFF 0			/* The identifier of state OFF in State Machine CrIaAlgo */
#define CrIaAlgo_ACTIVE 1		/* The identifier of state ACTIVE in State Machine CrIaAlgo */
#define CrIaAlgo_INACTIVE 2		/* The identifier of state INACTIVE in State Machine CrIaAlgo */
#define CrIaAlgo_SUSPENDED 3		/* The identifier of state SUSPENDED in State Machine CrIaAlgo */

/** The identifiers of transition commands (triggers) */
#define Stop 25
#define Resume 26
#define Suspend 27
#define Start 28

/**
 * Create a new state machine descriptor.
 * This interface creates the state machine descriptor dynamically.
 * @param smData the pointer to the state machine data.
 * A value of NULL is legal (note that the default value of the pointer
 * to the state machine data when the state machine is created is NULL).
 * @return the pointer to the state machine descriptor
 */
FwSmDesc_t CrIaAlgoCreate(void* smData);

/**
 * Entry Action for the state ACTIVE.
 * Initialization Action
 * @param smDesc the state machine descriptor
 */
void CrIaAlgoInitialization(FwSmDesc_t smDesc);

/**
 * Do Action for the state ACTIVE.
 * if (Flag_1) Execution Action
 * @param smDesc the state machine descriptor
 */
void CrIaAlgoActiveDoAction(FwSmDesc_t smDesc);

/**
 * Guard on the transition from INACTIVE to ACTIVE.
 * <pre>
 *  Algorithm 
 * is Enabled 
 * </pre>
 * @param smDesc the state machine descriptor
 * @return 1 if the guard is fulfilled, otherwise 0.
 */
FwSmBool_t CrIaAlgoIsAlgoEnabled(FwSmDesc_t smDesc);

/**
 * Action on the transition from SUSPENDED to INACTIVE.
 * Finalization Action
 * @param smDesc the state machine descriptor
 */
void CrIaAlgoFinalization(FwSmDesc_t smDesc);

#endif /* CrIaAlgoCreate_H_ */
