/**
 * @file
 * This header file declares the function to create one instance of the CrIaFdCheck state machine.
 * The state machine is configured with a set of function pointers representing the non-default
 * actions and guards of the state machine. Some of these functions may also be declared in
 * this header file in accordance with the configuration of the state machine in the FW Profile
 * Editor. In the latter case, the user has to provide an implementation for these functions
 * in a user-supplied body file.
 *
 * This header file has been automatically generated by the FW Profile Editor.
 * The state machine created by this file is shown in the figure below.
 * @image html CrIaFdCheck.png
 *
 * @author FW Profile code generator version 4.63
 * @date Created on: May 25 2016 8:50:47
 */

/** Make sure to include this header file only once */
#ifndef CrIaFdCheckCreate_H_
#define CrIaFdCheckCreate_H_

/** FW Profile function definitions */
#include "FwProfile/FwSmConstants.h"

/** State identifiers */
#define CrIaFdCheck_DISABLED (1)		/* The identifier of state DISABLED in State Machine CrIaFdCheck */
#define CrIaFdCheck_FAILED (4)		/* NOTE: wrong identifier! The identifier of state FAILED in State Machine CrIaFdCheck */
#define CrIaFdCheck_NOMINAL (2)		/* NOTE: wrong identifier! The identifier of state NOMINAL in State Machine CrIaFdCheck */
#define CrIaFdCheck_SUSPECTED (3)		/* NOTE: wrong identifier! The identifier of state SUSPECTED in State Machine CrIaFdCheck */

/** The identifiers of transition commands (triggers) */
#define Execute (0)

/**
 * Create a new state machine descriptor.
 * This interface creates the state machine descriptor dynamically.
 * @param smData the pointer to the state machine data.
 * A value of NULL is legal (note that the default value of the pointer
 * to the state machine data when the state machine is created is NULL).
 * @return the pointer to the state machine descriptor
 */
FwSmDesc_t CrIaFdCheckCreate(void* smData);

/**
 * Entry Action for the state NOMINAL.
 * Set FdCheckCnt to 1
 * @param smDesc the state machine descriptor
 */
void CrIaFdCheckNominalEntry(FwSmDesc_t smDesc);

/**
 * Do Action for the state NOMINAL.
 * Anomaly Detection Check
 * @param smDesc the state machine descriptor
 */
void CrIaFdCheckNominalDo(FwSmDesc_t smDesc);

/**
 * Entry Action for the state SUSPECTED.
 * <pre>
 * Increment FdCheckCnt
 * Increment FdCheckSpCnt
 * </pre>
 * @param smDesc the state machine descriptor
 */
void CrIaFdCheckSuspectedEntry(FwSmDesc_t smDesc);

/**
 * Do Action for the state SUSPECTED.
 * Anomaly Detection Check
 * @param smDesc the state machine descriptor
 */
void CrIaFdCheckSuspectedDo(FwSmDesc_t smDesc);

/**
 * Entry Action for the state FAILED.
 * Try Recovery
 * @param smDesc the state machine descriptor
 */
void CrIaFdCheckFailedEntry(FwSmDesc_t smDesc);

/**
 * Do Action for the state FAILED.
 * <pre>
 * Anomaly Detection Check;
 * if (Anomaly Detected) TryRecovery
 * </pre>
 * @param smDesc the state machine descriptor
 */
void CrIaFdCheckFailedDo(FwSmDesc_t smDesc);

/**
 * Exit Action for the state DISABLED.
 * <pre>
 * FdCheckCounter = 0;
 * Initialize Anomaly Detection Check
 * </pre>
 * @param smDesc the state machine descriptor
 */
void CrIaFdCheckDisabledExit(FwSmDesc_t smDesc);

/**
 * Guard on the transition from NOMINAL to DISABLED.
 * <pre>
 *  FdCheck is
 * not Enabled 
 * </pre>
 * @param smDesc the state machine descriptor
 * @return 1 if the guard is fulfilled, otherwise 0.
 */
FwSmBool_t CrIaFdCheckIsNotEnabled(FwSmDesc_t smDesc);

/**
 * Guard on the transition from FAILED to CHOICE1.
 *  (FdCheck is Enabled) && (No Anomaly) 
 * @param smDesc the state machine descriptor
 * @return 1 if the guard is fulfilled, otherwise 0.
 */
FwSmBool_t CrIaFdCheckIsAnomalyAndEnabled(FwSmDesc_t smDesc);

/**
 * Action on the transition from DISABLED to CHOICE1.
 * Do Anomaly Detection Check
 * @param smDesc the state machine descriptor
 */
void CrIaFdCheckAnomalyDetCheck(FwSmDesc_t smDesc);

/**
 * Guard on the transition from DISABLED to CHOICE1.
 *  FdCheck is Enabled 
 * @param smDesc the state machine descriptor
 * @return 1 if the guard is fulfilled, otherwise 0.
 */
FwSmBool_t CrIaFdCheckIsEnabled(FwSmDesc_t smDesc);

/**
 * Action on the transition from Initial State to DISABLED.
 * FdCheckSpCnt = 0
 * @param smDesc the state machine descriptor
 */
void CrIaFdCheckResetSpCnt(FwSmDesc_t smDesc);

/**
 * Guard on the transition from CHOICE1 to SUSPECTED.
 * <pre>
 *  (Anomaly Detected) &&
 * (FdCheckCnt < FdCheckCntThr) 
 * </pre>
 * @param smDesc the state machine descriptor
 * @return 1 if the guard is fulfilled, otherwise 0.
 */
FwSmBool_t CrIaFdCheckIsAnomalyAndSmallCnt(FwSmDesc_t smDesc);

/**
 * Guard on the transition from CHOICE1 to NOMINAL.
 *  No Anomaly 
 * @param smDesc the state machine descriptor
 * @return 1 if the guard is fulfilled, otherwise 0.
 */
FwSmBool_t CrIaFdCheckIsNoAnomaly(FwSmDesc_t smDesc);

/**
 * Action on the transition from CHOICE1 to FAILED.
 *  Generate evt rep. EVT_FD_FAILED
 * @param smDesc the state machine descriptor
 */
void CrIaFdCheckEvtFailed(FwSmDesc_t smDesc);

#endif /* CrIaFdCheckCreate_H_ */
