/**
 * @file
 * This header file declares the function to create one instance of the CrIaHbSemMon procedure.
 * The procedure is configured with a set of function pointers representing the non-default
 * actions and guards of the procedure. Some of these functions may also be declared in
 * this header file in accordance with the configuration of the procedure in the FW Profile
 * Editor. In the latter case, the user has to provide an implementation for these functions
 * in a user-supplied body file.
 *
 * This header file has been automatically generated by the FW Profile Editor.
 * The procedure created by this file is shown in the figure below.
 * @image html CrIaHbSemMon.png
 *
 * @author FW Profile code generator version 5.01
 * @date Created on: Sep 22 2017 14:47:10
 */

/** Make sure to include this header file only once */
#ifndef CRIAHBSEMMON_H_
#define CRIAHBSEMMON_H_

/** FW Profile function definitions */
#include "FwPrConstants.h"

/** Action node identifiers */
#define CrIaHbSemMon_N1 (1)		/* The identifier of action node N1 in procedure CrIaHbSemMon */
#define CrIaHbSemMon_N2 (2)		/* The identifier of action node N2 in procedure CrIaHbSemMon */
#define CrIaHbSemMon_N3 (3)		/* The identifier of action node N3 in procedure CrIaHbSemMon */
#define CrIaHbSemMon_N4 (4)		/* The identifier of action node N4 in procedure CrIaHbSemMon */
#define CrIaHbSemMon_N7 (5)		/* The identifier of action node N7 in procedure CrIaHbSemMon */
#define CrIaHbSemMon_N8 (6)		/* The identifier of action node N8 in procedure CrIaHbSemMon */
#define CrIaHbSemMon_N9 (7)		/* The identifier of action node N9 in procedure CrIaHbSemMon */

/**
 * Create a new procedure descriptor.
 * This interface creates the procedure descriptor dynamically.
 * @param prData the pointer to the procedure data.
 * A value of NULL is legal (note that the default value of the pointer
 * to the procedure data when the procedure is created is NULL).
 * @return the pointer to the procedure descriptor
 */
FwPrDesc_t CrIaHbSemMonCreate(void* prData);

/**
 * Action for node N1.
 * <pre>
 * Set hbSemPassword
 * and hbSemCounter to zero
 * </pre>
 * @param smDesc the procedure descriptor
 */
void CrIaHbSemMonN1(FwPrDesc_t prDesc);

/**
 * Action for node N2.
 * <pre>
 * Set hbSemCounter
 * to zero
 * </pre>
 * @param smDesc the procedure descriptor
 */
void CrIaHbSemMonN2(FwPrDesc_t prDesc);

/**
 * Action for node N3.
 * <pre>
 * Read SEM ON/OFF status
 * from DPU Status Register
 * </pre>
 * @param smDesc the procedure descriptor
 */
void CrIaHbSemMonN3(FwPrDesc_t prDesc);

/**
 * Action for node N4.
 * <pre>
 * Increment
 * hbSemCounter
 * </pre>
 * @param smDesc the procedure descriptor
 */
void CrIaHbSemMonN4(FwPrDesc_t prDesc);

/**
 * Action for node N7.
 * <pre>
 * Make entry
 * HBSEM_ALARM
 * in Error Log
 * </pre>
 * @param smDesc the procedure descriptor
 */
void CrIaHbSemMonN7(FwPrDesc_t prDesc);

/**
 * Action for node N8.
 * NOP
 * @param smDesc the procedure descriptor
 */
void CrIaHbSemMonN8(FwPrDesc_t prDesc);

/**
 * Action for node N9.
 * <pre>
 * Trigger
 * DPU Reset
 * </pre>
 * @param smDesc the procedure descriptor
 */
void CrIaHbSemMonN9(FwPrDesc_t prDesc);

/**
 * Guard on the Control Flow from DECISION1 to N2.
 * <pre>
 * hbSemPassword is
 * equal to 0xAA55 
 * </pre>
 * @param smDesc the procedure descriptor
 * @return 1 if the guard is fulfilled, otherwise 0.
 */
FwPrBool_t CrIaHbSemMonG2(FwPrDesc_t prDesc);

/**
 * Guard on the Control Flow from DECISION2 to N4.
 * <pre>
 * (hbSem is equal to FALSE) &&
 * (SEM ON/OFF flag is equal to OFF) 
 * </pre>
 * @param smDesc the procedure descriptor
 * @return 1 if the guard is fulfilled, otherwise 0.
 */
FwPrBool_t CrIaHbSemMonG21(FwPrDesc_t prDesc);

/**
 * Guard on the Control Flow from DECISION2 to N2.
 * <pre>
 * HbSem is
 * equal to TRUE
 * </pre>
 * @param smDesc the procedure descriptor
 * @return 1 if the guard is fulfilled, otherwise 0.
 */
FwPrBool_t CrIaHbSemMonG22(FwPrDesc_t prDesc);

/**
 * Guard on the Control Flow from DECISION3 to N8.
 * <pre>
 * hbSemCounter is
 * smaller than HBSEM_MON_LIM 
 * </pre>
 * @param smDesc the procedure descriptor
 * @return 1 if the guard is fulfilled, otherwise 0.
 */
FwPrBool_t CrIaHbSemMonG4(FwPrDesc_t prDesc);

/**
 * Guard on the Control Flow from DECISION4 to N4.
 * <pre>
 * (SEM Mode as given by data pool variables
 * echoing SEM telemetry is STANDBY or SAFE) &&
 * (HbSem is equal to FALSE) 
 * </pre>
 * @param smDesc the procedure descriptor
 * @return 1 if the guard is fulfilled, otherwise 0.
 */
FwPrBool_t CrIaHbSemMonG3(FwPrDesc_t prDesc);

/**
 * Guard on the Control Flow from N8 to DECISION1.
 * Wait 1 Cycle  
 * @param smDesc the procedure descriptor
 * @return 1 if the guard is fulfilled, otherwise 0.
 */
FwPrBool_t CrIaHbSemMonG1(FwPrDesc_t prDesc);

#endif /* CrIaHbSemMonCreate_H_ */