/**
 * @file
 * This header file declares the function to create one instance of the CrIaSem state machine.
 * The state machine is configured with a set of function pointers representing the non-default
 * actions and guards of the state machine. Some of these functions may also be declared in
 * this header file in accordance with the configuration of the state machine in the FW Profile
 * Editor. In the latter case, the user has to provide an implementation for these functions
 * in a user-supplied body file.
 *
 * This header file has been automatically generated by the FW Profile Editor.
 * The state machine created by this file is shown in the figure below.
 *
 * <b>Note for state OPER</b>
 * State OPER contains an embedded state 
 * machine (the SEM Operation State Machine).
 *
 * @image html CrIaSem.png
 *
 * @author FW Profile code generator version 5.01
 * @date Created on: Aug 13 2018 18:55:30
 */

/** Make sure to include this header file only once */
#ifndef CrIaSemCreate_H_
#define CrIaSemCreate_H_

/** FW Profile function definitions */
#include "FwProfile/FwSmConstants.h"

/** State identifiers */
#define CrIaSem_STOPPED (0)
#define CrIaSem_CCD_FULL (1)		/* The identifier of state CCD_FULL in State Machine CrIaSem */
#define CrIaSem_CCD_WINDOW (2)		/* The identifier of state CCD_WINDOW in State Machine CrIaSem */
#define CrIaSem_DIAGNOSTICS (3)		/* The identifier of state DIAGNOSTICS in State Machine CrIaSem */
#define CrIaSem_STABILIZE (4)		/* The identifier of state STABILIZE in State Machine CrIaSem */
#define CrIaSem_STANDBY (5)		/* The identifier of state STANDBY in State Machine CrIaSem */
#define CrIaSem_TR_CCD_FULL (6)		/* The identifier of state TR_CCD_FULL in State Machine CrIaSem */
#define CrIaSem_TR_CCD_WINDOW (7)		/* The identifier of state TR_CCD_WINDOW in State Machine CrIaSem */
#define CrIaSem_TR_STABILIZE (8)		/* The identifier of state TR_STABILIZE in State Machine CrIaSem */
#define CrIaSem_INIT (1)		/* The identifier of state INIT in State Machine CrIaSem */
#define CrIaSem_OFF (2)		/* The identifier of state OFF in State Machine CrIaSem */
#define CrIaSem_OPER (3)		/* The identifier of state OPER in State Machine CrIaSem */
#define CrIaSem_SAFE (4)		/* The identifier of state SAFE in State Machine CrIaSem */
#define CrIaSem_SHUTDOWN (5)		/* The identifier of state SHUTDOWN in State Machine CrIaSem */

/** The identifiers of transition commands (triggers) */
#define Execute (0)
#define SwitchOn (6)
#define SwitchOff (7)
#define GoToSafe (8)
#define GoToStandby (9)
#define GoToStabilize (10)
#define GoToCcdWindow (11)
#define GoToCcdFull (12)
#define GoToDiagnostics (13)

/**
 * Create a new state machine descriptor.
 * This interface creates the state machine descriptor dynamically.
 * @param smData the pointer to the state machine data.
 * A value of NULL is legal (note that the default value of the pointer
 * to the state machine data when the state machine is created is NULL).
 * @return the pointer to the state machine descriptor
 */
FwSmDesc_t CrIaSemCreate(void* smData);

/**
 * Entry Action for the state STANDBY.
 * Load EVT_SEMOP_TR
 * @param smDesc the state machine descriptor
 */
void CrIaSemOperLdTransEvt(FwSmDesc_t smDesc);

/**
 * Do Action for the state TR_STABILIZE.
 * <pre>
 * if (Flag_3) { Send command 
 *  FPM_Power_Enable to SEM;
 *  Send cmd(220,11) to SEM }
 * </pre>
 * @param smDesc the state machine descriptor
 */
void CrIaSemOperTrStabilizeDo(FwSmDesc_t smDesc);

/**
 * Entry Action for the state STABILIZE.
 * <pre>
 * Load EVT_SEMOP_TR;
 * Disable TTM FdCheck;
 * </pre>
 * @param smDesc the state machine descriptor
 */
void CrIaSemOperStabilizeEntry(FwSmDesc_t smDesc);

/**
 * Entry Action for the state TR_CCD_WINDOW.
 * <pre>
 * Load EVT_SEMOP_TR
 * Enable TTM FdCheck;
 * acqImageCnt = 0;
 * </pre>
 * @param smDesc the state machine descriptor
 */
void CrIaSemOperTrCcdWindowEntry(FwSmDesc_t smDesc);

/**
 * Entry Action for the state TR_CCD_FULL.
 * <pre>
 * Load EVT_SEMOP_TR
 * Enable TTM FdCheck;
 * acqImageCnt = 0;
 * </pre>
 * @param smDesc the state machine descriptor
 */
void CrIaSemOperTrCcdFullEntry(FwSmDesc_t smDesc);

/**
 * Entry Action for the state CCD_WINDOW.
 * <pre>
 * Load EVT_SEMOP_TR;
 * imageCycleCnt = -1;
 * </pre>
 * @param smDesc the state machine descriptor
 */
void CrIaSemOperCcdWindowEntry(FwSmDesc_t smDesc);

/**
 * Exit Action for the state CCD_WINDOW.
 * ImageCycleCnt = -1
 * @param smDesc the state machine descriptor
 */
void CrIaSemOperCcdWindowExit(FwSmDesc_t smDesc);

/**
 * Do Action for the state CCD_WINDOW.
 * <pre>
 * if (Flag_4) imageCycleCnt++;
 * if (Flag_1) {
 *   acqImageCnt++;
 *    imageCycleCnt = 0 };
 * if (Flag_2)
 *    notify Sporadic Activity 2;
 * </pre>
 * @param smDesc the state machine descriptor
 */
void CrIaSemOperCcdWindowDo(FwSmDesc_t smDesc);

/**
 * Entry Action for the state CCD_FULL.
 * <pre>
 * Load EVT_SEMOP_TR;
 * imageCycleCnt = -1;
 * </pre>
 * @param smDesc the state machine descriptor
 */
void CrIaSemOperCcdFullEntry(FwSmDesc_t smDesc);

/**
 * Exit Action for the state CCD_FULL.
 * ImageCycleCnt = -1
 * @param smDesc the state machine descriptor
 */
void CrIaSemOperCcdFullExit(FwSmDesc_t smDesc);

/**
 * Do Action for the state CCD_FULL.
 * <pre>
 * if (Flag_4) imageCycleCnt++;
 * if (Flag_1) {
 *    acqImageCnt++;
 *    imageCycleCnt = 0 };
 * if (imageCycleCnt == ACQ_PH)
 *    notify Sporadic Activity 1;
 * if (Flag_2)
 *    notify Sporadic Activity 2;
 * </pre>
 * @param smDesc the state machine descriptor
 */
void CrIaSemOperCcdFullDo(FwSmDesc_t smDesc);

/**
 * Action on the transition from STANDBY to TR_STABILIZE.
 * CMD_Temp_Control_Enable
 * @param smDesc the state machine descriptor
 */
void CrIaSemOperCmdTempControlEnable(FwSmDesc_t smDesc);

/**
 * Guard on the transition from TR_STABILIZE to STABILIZE.
 *  Flag_4 
 * @param smDesc the state machine descriptor
 * @return 1 if the guard is fulfilled, otherwise 0.
 */
FwSmBool_t CrIaSemOperIsTempStabilized(FwSmDesc_t smDesc);

/**
 * Action on the transition from STABILIZE to TR_CCD_WINDOW.
 * CMD_CCD_Data_Enable
 * @param smDesc the state machine descriptor
 */
void CrIaSemOperCmdCcdDataEnable(FwSmDesc_t smDesc);

/**
 * Action on the transition from STABILIZE to DIAGNOSTICS.
 * CMD_Diagnostics_Enable
 * @param smDesc the state machine descriptor
 */
void CrIaSemOperCmdDiagEnable(FwSmDesc_t smDesc);

/**
 * Guard on the transition from TR_CCD_WINDOW to STABILIZE.
 * <pre>
 *  SEM Evt
 * Confirms
 * STABILIZE 
 * </pre>
 * @param smDesc the state machine descriptor
 * @return 1 if the guard is fulfilled, otherwise 0.
 */
FwSmBool_t CrIaSemOperIsInStabilize(FwSmDesc_t smDesc);

/**
 * Guard on the transition from TR_CCD_WINDOW to CCD_WINDOW.
 * <pre>
 *  SEM
 * Evt Confirms
 * SCIENCE 
 * </pre>
 * @param smDesc the state machine descriptor
 * @return 1 if the guard is fulfilled, otherwise 0.
 */
FwSmBool_t CrIaSemOperIsInScience(FwSmDesc_t smDesc);

/**
 * Guard on the transition from TR_CCD_FULL to CCD_FULL.
 * <pre>
 *  SEM
 * Evt Confirms
 * CCD_FULL 
 * </pre>
 * @param smDesc the state machine descriptor
 * @return 1 if the guard is fulfilled, otherwise 0.
 */
FwSmBool_t CrIaSemOperIsInCcdFull(FwSmDesc_t smDesc);

/**
 * Action on the transition from CCD_WINDOW to TR_CCD_WINDOW.
 * <pre>
 * 
 * CMD_CCD_Data_Disable
 * </pre>
 * @param smDesc the state machine descriptor
 */
void CrIaSemOperCmdCcdDataDisable(FwSmDesc_t smDesc);

/**
 * Entry Action for the state OFF.
 * <pre>
 * if (Entry in OFF is not part of Starting
 *  the SM) then  Load EVT_SEM_TR
 * </pre>
 * @param smDesc the state machine descriptor
 */
void CrIaSemLdTransEvt(FwSmDesc_t smDesc);

/**
 * Entry Action for the state INIT.
 * <pre>
 * Load EVT_SEM_TR;
 * Reset Source Seq. Counter for SEM
 * Enable SEM Comm. Error FdCheck;
 * Enable SEM Mode Time-Out FdCheck;
 * Enable SEM Safe Mode FdCheck;
 * Enable SEM Anomaly Event FdCheck;
 * Enable TM Packet SEM_ABS_HK;
 * </pre>
 * @param smDesc the state machine descriptor
 */
void CrIaSemInitEntry(FwSmDesc_t smDesc);

/**
 * Exit Action for the state INIT.
 * <pre>
 * Stop SEM Initialization Procedure;
 * Enable SEM Alive FdCheck;
 * Enable SEM Limit FdCheck;
 * Load TC(9,129) to SEM;
 * Enable SEM Mode Cons. FdCheck
 * </pre>
 * @param smDesc the state machine descriptor
 */
void CrIaSemInitExit(FwSmDesc_t smDesc);

/**
 * Do Action for the state INIT.
 * Execute SEM Initialization Procedure
 * @param smDesc the state machine descriptor
 */
void CrIaSemInitDo(FwSmDesc_t smDesc);

/**
 * Entry Action for the state SHUTDOWN.
 * <pre>
 * Load EVT_SEM_TR;
 * Start SEM ShutdownProcedure;
 * Disable SEM-related FdChecks;
 * Disable TM Packet SEM_ABS_HK;
 * </pre>
 * @param smDesc the state machine descriptor
 */
void CrIaSemShutdownEntry(FwSmDesc_t smDesc);

/**
 * Do Action for the state SHUTDOWN.
 * Execute SEM Shutdown Procedure
 * @param smDesc the state machine descriptor
 */
void CrIaSemShutdownDo(FwSmDesc_t smDesc);

/**
 * Exit Action for the state OPER.
 * Disable TTM FdCheck
 * @param smDesc the state machine descriptor
 */
void CrIaSemOperExit(FwSmDesc_t smDesc);

/**
 * Action on the transition from OFF to INIT.
 * Start SEM Initialization Proc.
 * @param smDesc the state machine descriptor
 */
void CrIaSemStartSemInitPr(FwSmDesc_t smDesc);

/**
 * Guard on the transition from INIT to OPER.
 * <pre>
 *  SEM Evnt Confirms 
 * Entry into STANDBY 
 * </pre>
 * @param smDesc the state machine descriptor
 * @return 1 if the guard is fulfilled, otherwise 0.
 */
FwSmBool_t CrIaSemIsSemInStandby(FwSmDesc_t smDesc);

/**
 * Guard on the transition from SHUTDOWN to OFF.
 * <pre>
 *  SEM Shutdown
 * Proc. Terminated 
 * </pre>
 * @param smDesc the state machine descriptor
 * @return 1 if the guard is fulfilled, otherwise 0.
 */
FwSmBool_t CrIaSemIsShutdownTerm(FwSmDesc_t smDesc);

/**
 * Guard on the transition from OPER to SAFE.
 * <pre>
 *  SEM Evt Confirms
 * Entry into SAFE 
 * </pre>
 * @param smDesc the state machine descriptor
 * @return 1 if the guard is fulfilled, otherwise 0.
 */
FwSmBool_t CrIaSemIsSemInSafe(FwSmDesc_t smDesc);

/**
 * Action on the transition from OPER to SAFE.
 * CMD_Safe_Enter
 * @param smDesc the state machine descriptor
 */
void CrIaSemGoToSafe(FwSmDesc_t smDesc);

/**
 * Action on the transition from OPER to INIT.
 * CMD_Standby_Enter
 * @param smDesc the state machine descriptor
 */
void CrIaSemGoToStandby(FwSmDesc_t smDesc);

#endif /* CrIaSemCreate_H_ */
